#! /usr/bin/env python
#
# preproc.py script
# dynamically generates pdmenu content, given
#       - config files in xenlabs
#       - flags and username passed from pdmenu
# Usage: python preproc.py -flag username
# Flags: 
#       --listall               Show all labs
#       --submenus              Generate submenus (shown: in labsmenu)
#

import sys, os
import datetime

import messages
from lab import *
from user import *

LOG_DIR = "/home/xenlabs/logs/"

# main()#{{{
# Creates a User object (lab profile) for the username $USER passed
# from Pdmenu. Creates menus and prints them to stdout, which is
# processed by Pdmenu to create the menu system seen by the user.
#
def main():
        # do sanity check on arguments
        if len(sys.argv) != 3:
                print "USAGE: preproc.py <flag> <username>"
                sys.exit(1)

        flag = sys.argv[1].strip("--")
        userName = sys.argv[2]

        # generates User object for $USER passed
        user = User(userName)

        # add logging
        try:
            logfname = "%s%s-%s" % (LOG_DIR, userName, datetime.datetime.now())
            logf = open(logfname, 'a')

            if flag == "listall":
                toplabs = user.generateLabListForPdmenu()
                # log the output to pdmenu
                logf.write(toplabs)
                print toplabs
            elif flag == "submenus":
                submenus = user.generateSubmenusForPdmenu()
                # log the output to pdmenu
                logf.write(submenus)
                print submenus
            else:
                    messages.error("Incorrect flag specified. Please \
                                    contact your system administrator.")

        except(IOError):
            print "Could not open log file %s" % logfname
            sys.exit()
        finally:
            logf.close()

if __name__ == "__main__":
        main()#}}}

# vim:fdm=marker
