# user.py

import sys, os
import messages
from lab import *
from world import *

class User:

	# __init__#{{{
	#
	# arguments
	# uname			Username
	# confp			Path for main configuration file
	#					defaults to "/home/xenlabs/main.cfg"
	#
	def __init__ (self, uname, confp="/home/xenlabs/main.cfg"):

		# Variables
		self.name = uname
		self.worlds = []

		# Load a list of the users current worlds
		labDirs = self.parseMainConfigFile(open(confp, 'r'))
		for dir in labDirs:
			l = XenWorld(self.name, dir)
			if l.isUser(self.name):
				self.worlds.append(l)

#}}}
	# generateLabListForPdmenu(self)#{{{
	# Generates the main (initial) list of labs available to the user.
	#
	def generateLabListForPdmenu(self):
		""" Returns list of this user's labs in pdmenu-speak 
		"""
		pdmenu=""
		for world in self.worlds:
			# add a submenu command to the pdmenu string
			# formula for submenu name: C+classNo+L+labNo
			pdmenu += "show:%s::%s\n" % (\
					world.classNo + " - Lab _" + \
					world.labNo + "\: " + world.labName, \
					"C"+world.classNo+"L"+world.labNo)
		return pdmenu

#}}}
	# generateSubmenusForPdmenu(self)#{{{
	# 
	def generateSubmenusForPdmenu(self):
		""" The Big Kahuna. Generates submenus, with appropriate reference calls
		to xl_vm_manager.sh, for all of the user's labs.
		"""
		slist=[]
		sPath="sudo /home/xenlabs/bin/xl_vm_manager.sh"
		for world in self.worlds:
			# write submenu header, format is menu:id:title:description
			slist.append("menu:%s:%s:%s" % (\
					"C"+world.classNo+"L"+world.labNo, \
					world.classNo + " - Lab " + world.labNo, \
					"This lab is due in..."))

			# write lab-specific submenus
			slist.append("show:_Connect::%s" \
					% "C"+world.classNo+"L"+world.labNo+"-Connect")
			slist.append("show:_VM Management::%s" \
					% "C"+world.classNo+"L"+world.labNo+"-ManageVMs")
			slist.append("show:_Snapshot::%s" \
					% "C"+world.classNo+"L"+world.labNo+"-Snapshot")
			slist.append("show:_Handin::%s" \
					% "C"+world.classNo+"L"+world.labNo+"-Handin")
			slist.append("exit:_Exit")

			# Connect to VM menu
			slist.append("menu:%s:%s:%s" % (\
					"C"+world.classNo+"L"+world.labNo+"-Connect", \
					"Connect to VM's", \
					"Please choose a VM to connect to"))
			for vm in world.vmList:
				slist.append("exec:_%s:pause:%s connect %s %s" \
						% (vm.vmId, sPath, vm.vmName, vm.xenFile))
			slist.append("exit:_Exit")

			# VM Management (list actions)
			slist.append("menu:%s:%s:%s" % (\
					"C"+world.classNo+"L"+world.labNo+"-ManageVMs", \
					"VM Management", \
					"Please choose an action"))
			slist.append("show:_Start::%s" \
					% "C"+world.classNo+"L"+world.labNo+"-StartVM")
			slist.append("show:_Shutdown::%s" \
					% "C"+world.classNo+"L"+world.labNo+"-ShutdownVM")
			slist.append("show:_Reboot::%s" \
					% "C"+world.classNo+"L"+world.labNo+"-RebootVM")
			slist.append("show:_Destroy::%s" \
					% "C"+world.classNo+"L"+world.labNo+"-DestroyVM")
			slist.append("exit:_Exit")

			# VM Management (list VM's)
			# for -StartVM
			slist.append("menu:%s:%s:%s" % (\
					"C"+world.classNo+"L"+world.labNo+"-StartVM", \
					"Start VM's", \
					"Choose a VM to start."))
			for vm in world.vmList:
				slist.append("exec:_%s:pause:%s start %s %s" \
						% (vm.vmId, sPath, vm.vmName, vm.xenFile))
			slist.append("exit:_Exit")
			# for -ShutdownVM
			slist.append("menu:%s:%s:%s" % (\
					"C"+world.classNo+"L"+world.labNo+"-ShutdownVM", \
					"Shutdown VM's", \
					"Choose a VM to shutdown."))
			for vm in world.vmList:
				slist.append("exec:_%s:pause:%s shutdown %s %s" \
						% (vm.vmId, sPath, vm.vmName, vm.xenFile))
			slist.append("exit:_Exit")
			# for -RebootVM
			slist.append("menu:%s:%s:%s" % (\
					"C"+world.classNo+"L"+world.labNo+"-RebootVM", \
					"Reboot VM's", \
					"Choose a VM to reboot."))
			for vm in world.vmList:
				slist.append("exec:_%s:pause:%s reboot %s %s" \
						% (vm.vmId, sPath, vm.vmName, vm.xenFile))
			slist.append("exit:_Exit")
			# for -destroyVM
			slist.append("menu:%s:%s:%s" % (\
					"C"+world.classNo+"L"+world.labNo+"-DestroyVM", \
					"Destroy VM's", \
					"Choose a VM to destroy."))
			for vm in world.vmList:
				slist.append("exec:_%s:pause:%s destroy %s %s" \
						% (vm.vmId, sPath, vm.vmName, vm.xenFile))
			slist.append("exit:_Exit")

			# Snapshot - not supported yet
			slist.append("menu:%s:%s:%s" % (\
					"C"+world.classNo+"L"+world.labNo+"-Snapshot", \
					"Snapshot", \
					"Manage snapshots of your VM's - not yet supported"))
			slist.append("exit:_Exit")

			# Handin
			slist.append("menu:%s:%s:%s" % (\
					"C"+world.classNo+"L"+world.labNo+"-Handin", \
					"Handin", \
					"Run handin program on this lab - not yet supported"))
			slist.append("exit:_Exit")

		return '\n'.join(slist)

#}}}
	# parseMainConfigFile(self, f)#{{{
	#
	def parseMainConfigFile(self, f):
		"""Returns a list of the lines in a file f, ignoring comments
		(marked with a # - no inline comments yet) and blank lines.
		"""
		lines=[]
		for line in f.readlines():
			if line.startswith("#"):
				pass
			elif line.startswith("\n"):
				pass
			else:
				lines.append(line.strip())
		return lines

#}}}
# main()#{{{
# for debugging porpoises
def main():
	u = User("grobinso")
	print u.generateLabListForPdmenu()
	print u.generateSubmenusForPdmenu()

if __name__ == "__main__":
	main()#}}}

# vim:fdm=marker
